import { csv, select } from 'd3'; // importing 'csv' and 'select' functions from d3
import { scatterPlot } from './scatterPlot'; // importing scatterPlot from local file scatterplot.js

// Url to the csv file containing data of iris flower.
const csvUrl = [
  'https://gist.githubusercontent.com/',
  'curran/', // User
  'a08a1080b88344b0c8a7/', // Id of the Gist
  'raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/', // commit
  'iris.csv', // File name
].join('');
const parseRow = (d) => { //converting csv data to javascript object.
  d.sepal_length = +d.sepal_length; // these properties are converted to numbers
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

//  giving the width and height of the svg element
const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => { // asunc function creates scatter plot from scatter plot function
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width) // SETTING X AND Y VALUES OF THE SCATTERPLOT 
    .yValue((d) => d.sepal_length)
    .margin({ // SETTING MARGIN AND RADIUS PROPERTIES OF THE SCATTER PLOT
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(5);

  svg.call(plot); // NOW SCATTER PLOT IS APPENDED TO SVG ELEMENT USING CALL METHOD.

  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  let i = 0;
  setInterval(() => { // setting up an interval that changes the xValue property of the scatter plot every two seconds
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
};
main();



